.. czifile documentation

.. currentmodule:: czifile

.. toctree::
   :hidden:
   :maxdepth: 2

czifile
=======

.. automodule:: czifile
   :members:
   :special-members:

.. include:: ../CHANGES.rst

License
=======

.. literalinclude:: ../LICENSE
